# Q+ROI+Proj Tool

Q+ROI+Proj Tool combines Angle/Q, ROI and Projections

Projections:

- Row/Column slice e.g. 9:10 or 100:120:2, <empty> for all
- Mapping: mean or sum

ROI:

- ROI alias(es) for roi tango devices
- Add to or Fetch from sardana environment
- Sum of the selected ROI or all ROIs. The used version can be selected in the configuration.

Geometry:

- Geometry: detector geometry parameters. They can be pass in both ways via LavueController tango server
- theta angles or q-space selects the radial transformation
- Pixel intensity pointed by mouse and its position